package main

import (
	"context"
	"log"
	"time"

	"go.mongodb.org/mongo-driver/mongo"
	"go.mongodb.org/mongo-driver/mongo/options"

	"database/sql"

	"github.com/go-sql-driver/mysql"
	_ "github.com/go-sql-driver/mysql"
)

var client mongo.Client
var colUsers *mongo.Collection
var mongoCtx context.Context

func init() {
	openMongoDBConnection()
	openMariaDBConnection()
}

func openMongoDBConnection() {
	// Mongo DB setup
	clientOptions := options.Client().ApplyURI("mongodb://" + config.MongoDbUser + ":" + config.MongoDbPass + "@" + config.MongoDbHost + ":" + config.MongoDbPort)
	client, err := mongo.NewClient(clientOptions)
	if err != nil {
		log.Fatal("DB Error: ", err)
	}
	// Cancel if Timeout
	ctx, cancel := context.WithTimeout(context.Background(), 20*time.Second)
	defer cancel()

	// Connect to DB
	err = client.Connect(ctx)
	if err != nil {
		log.Fatal("DB Error: ", err)
	}

	colUsers = client.Database("bs1in").Collection("users")
}

func openMariaDBConnection() {
	dbConf := mysql.Config{
		User:                 config.MariaDbUser,
		Passwd:               config.MariaDbPass,
		Net:                  "tcp",
		Addr:                 config.MariaDbHost + ":" + config.MariaDbPort,
		AllowNativePasswords: true, // Without this it did not work...
	}
	mariadb, err := sql.Open("mysql", dbConf.FormatDSN())
	if err != nil {
		log.Fatal("MariaDB Connection Error: ", err)
	}

	err = mariadb.Ping()
	if err != nil {
		log.Fatal("MariaDB not reachable (Ping Error): ", err)
	}

	var version string
	mariadb.QueryRow("SELECT VERSION()").Scan(&version)
	log.Println("Connected to:", version)
}
